<?php
/**
 * Adds the header options sections, settings, and controls to the theme customizer
 *
 * @package Stygian
 */

class Stygian_Header_Options {
	public function __construct() {
		// Register Header Options.
		add_action( 'customize_register', array( $this, 'register_header_options' ) );
	}

	/**
	 * Add header options section and its controls
	 */
	public function register_header_options( $wp_customize ) {
		// Add header options section.
		$wp_customize->add_section( 'stygian_header_options',
			array(
				'title' => esc_html__( 'Header Options', 'stygian' ),
				'panel' => 'stygian_theme_options'
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'text',
				'settings'          => 'stygian_header_email',
				'sanitize_callback' => 'sanitize_email',
				'label'             => esc_html__( 'Email', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'text',
				'settings'          => 'stygian_header_phone',
				'sanitize_callback' => 'stygian_text_sanitization',
				'label'             => esc_html__( 'Phone', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'text',
				'settings'          => 'stygian_header_address',
				'sanitize_callback' => 'stygian_text_sanitization',
				'label'             => esc_html__( 'Address', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'text',
				'settings'          => 'stygian_header_open_hours',
				'sanitize_callback' => 'stygian_text_sanitization',
				'label'             => esc_html__( 'Open Hours', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'text',
				'settings'          => 'stygian_header_button_text',
				'sanitize_callback' => 'stygian_text_sanitization',
				'label'             => esc_html__( 'Button Text', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'url',
				'settings'          => 'stygian_header_button_link',
				'sanitize_callback' => 'esc_url_raw',
				'label'             => esc_html__( 'Button Link', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'custom_control'    => 'Stygian_Toggle_Switch_Custom_control',
				'settings'          => 'stygian_header_button_target',
				'sanitize_callback' => 'stygian_switch_sanitization',
				'label'             => esc_html__( 'Open link in new tab?', 'stygian' ),
				'section'           => 'stygian_header_options',
			)
		);
	}
}

/**
 * Initialize class
 */
$stygian_theme_options = new Stygian_Header_Options();
